@@ -56,7 +56,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KMessageWidget>
-#include <KNotificationRestrictions>
 #include <KProtocolManager>
 #include <KRecentFilesAction>
 #include <KStandardShortcut>
@@ -115,6 +114,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #ifdef HAVE_QTDBUS
 #include <QDBusConnection>
 #include <QDBusPendingReply>
+#include <QDBusReply>
 #include <lib/mpris2/mpris2service.h>
 #endif
 #include <lib/print/printhelper.h>
@@ -233,7 +233,7 @@ struct MainWindow::Private {
     MainPageId mCurrentMainPageId;
 
     QDateTime mFullScreenLeftAt;
-    KNotificationRestrictions *mNotificationRestrictions = nullptr;
+    uint screenSaverDbusCookie = 0;
 
     void setupContextManager()
     {
@@ -511,7 +511,12 @@ struct MainWindow::Private {
 
 #if HAVE_PURPOSE
         mShareAction = new KToolBarPopupAction(QIcon::fromTheme(QStringLiteral("document-share")), i18nc("@action Share images", "Share"), q);
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         mShareAction->setPopupMode(QToolButton::InstantPopup);
+#else
+        mShareAction->setPopupMode(KToolBarPopupAction::InstantPopup);
+#endif
         actionCollection->addAction(QStringLiteral("share"), mShareAction);
         mShareMenu = new Purpose::Menu(q);
         mShareAction->setMenu(mShareMenu);
@@ -927,13 +932,30 @@ struct MainWindow::Private {
 
     void setScreenSaverEnabled(bool enabled)
     {
-        // Always delete mNotificationRestrictions, it does not hurt
-        delete mNotificationRestrictions;
-        if (!enabled) {
-            mNotificationRestrictions = new KNotificationRestrictions(KNotificationRestrictions::ScreenSaver, q);
+#ifdef HAVE_QTDBUS
+        if (enabled) {
+            QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                                  QStringLiteral("/ScreenSaver"),
+                                                                  QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                                  QStringLiteral("Inhibit"));
+            message << QGuiApplication::desktopFileName();
+            message << i18n("Viewing media");
+            QDBusReply<uint> reply = QDBusConnection::sessionBus().call(message);
+            if (reply.isValid()) {
+                screenSaverDbusCookie = reply.value();
+            }
         } else {
-            mNotificationRestrictions = nullptr;
+            if (screenSaverDbusCookie != 0) {
+                QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                                      QStringLiteral("/ScreenSaver"),
+                                                                      QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                                      QStringLiteral("UnInhibit"));
+                message << static_cast<uint>(screenSaverDbusCookie);
+                screenSaverDbusCookie = 0;
+                QDBusConnection::sessionBus().send(message);
+            }
         }
+#endif
     }
 
     void assignThumbnailProviderToThumbnailView(ThumbnailView *thumbnailView)
@@ -1035,7 +1057,6 @@ MainWindow::MainWindow()
     d->setupThumbnailBarModel();
     d->mGvCore = new GvCore(this, d->mDirModel);
     d->mPreloader = new Preloader(this);
-    d->mNotificationRestrictions = nullptr;
     d->mThumbnailProvider = new ThumbnailProvider();
     d->mActiveThumbnailView = nullptr;
     d->initDirModel();
@@ -1120,54 +1141,8 @@ void MainWindow::setInitialUrl(const QUrl &_url)
 {
     Q_ASSERT(_url.isValid());
     QUrl url = UrlUtils::fixUserEnteredUrl(_url);
-#ifdef HAVE_QTDBUS
-    QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.FileManager1"),
-                                                          QStringLiteral("/org/freedesktop/FileManager1"),
-                                                          QStringLiteral("org.freedesktop.FileManager1"),
-                                                          QStringLiteral("SortOrderForUrl"));
-
-    QUrl dirUrl = url;
-    dirUrl = dirUrl.adjusted(QUrl::RemoveFilename);
-    message << dirUrl.toString();
-
-    QDBusPendingCall call = QDBusConnection::sessionBus().asyncCall(message);
-    auto watcher = new QDBusPendingCallWatcher(call, this);
-
-    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *call) {
-        QDBusPendingReply<QString, QString> reply = *call;
-        // Fail silently
-        if (!reply.isError()) {
-            QString columnName = reply.argumentAt<0>();
-            QString orderName = reply.argumentAt<1>();
-
-            int column = -1;
-            int sortRole = -1;
-            Qt::SortOrder order = orderName == QStringLiteral("descending") ? Qt::DescendingOrder : Qt::AscendingOrder;
-
-            if (columnName == "text") {
-                column = KDirModel::Name;
-                sortRole = Qt::DisplayRole;
-            } else if (columnName == "modificationtime") {
-                column = KDirModel::ModifiedTime;
-                sortRole = Qt::DisplayRole;
-            } else if (columnName == "size") {
-                column = KDirModel::Size;
-                sortRole = Qt::DisplayRole;
-#ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
-            } else if (columnName == "rating") {
-                column = KDirModel::Name;
-                sortRole = SemanticInfoDirModel::RatingRole;
-#endif
-            }
-
-            if (column >= 0 && sortRole >= 0) {
-                d->mDirModel->setSortRole(sortRole);
-                d->mDirModel->sort(column, order);
-            }
-        }
-        call->deleteLater();
-    });
-#endif
+    d->mGvCore->setTrackFileManagerSorting(true);
+    syncSortOrder(url);
 
     if (UrlUtils::urlIsDirectory(url)) {
         d->mBrowseAction->trigger();
@@ -1223,6 +1198,7 @@ void MainWindow::slotThumbnailViewIndexActivated(const QModelIndex &index)
     }
 
     KFileItem item = d->mDirModel->itemForIndex(index);
+    syncSortOrder(item.url());
     if (item.isDir()) {
         // Item is a dir, open it
         openDirUrl(item.url());
@@ -1371,6 +1347,66 @@ void MainWindow::folderViewUrlChanged(const QUrl &url)
     }
 }
 
+void MainWindow::syncSortOrder(const QUrl &url)
+{
+    if (!d->mGvCore->trackFileManagerSorting()) {
+        return;
+    }
+
+#ifdef HAVE_QTDBUS
+    QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.FileManager1"),
+                                                          QStringLiteral("/org/freedesktop/FileManager1"),
+                                                          QStringLiteral("org.freedesktop.FileManager1"),
+                                                          QStringLiteral("SortOrderForUrl"));
+
+    QUrl dirUrl = url;
+    dirUrl = dirUrl.adjusted(QUrl::RemoveFilename);
+    message << dirUrl.toString();
+
+    QDBusPendingCall call = QDBusConnection::sessionBus().asyncCall(message);
+    auto watcher = new QDBusPendingCallWatcher(call, this);
+
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *call) {
+        QDBusPendingReply<QString, QString> reply = *call;
+        // Fail silently
+        if (!reply.isError()) {
+            QString columnName = reply.argumentAt<0>();
+            QString orderName = reply.argumentAt<1>();
+
+            int column = -1;
+            int sortRole = -1;
+            Qt::SortOrder order = orderName == QStringLiteral("descending") ? Qt::DescendingOrder : Qt::AscendingOrder;
+
+            if (columnName == "text") {
+                column = KDirModel::Name;
+                sortRole = Qt::DisplayRole;
+                qCDebug(GWENVIEW_APP_LOG) << "Sorting according to file manager: text";
+            } else if (columnName == "modificationtime") {
+                column = KDirModel::ModifiedTime;
+                sortRole = Qt::DisplayRole;
+                qCDebug(GWENVIEW_APP_LOG) << "Sorting according to file manager: modtime";
+            } else if (columnName == "size") {
+                column = KDirModel::Size;
+                sortRole = Qt::DisplayRole;
+                qCDebug(GWENVIEW_APP_LOG) << "Sorting according to file manager: size";
+#ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
+            } else if (columnName == "rating") {
+                column = KDirModel::Name;
+                sortRole = SemanticInfoDirModel::RatingRole;
+                qCDebug(GWENVIEW_APP_LOG) << "Sorting according to file manager: rating";
+#endif
+            }
+
+            if (column >= 0 && sortRole >= 0) {
+                d->mDirModel->setSortRole(sortRole);
+                d->mDirModel->sort(column, order);
+            }
+        }
+        call->deleteLater();
+    });
+#endif
+}
+
 void MainWindow::toggleSideBar(bool visible)
 {
     d->saveSplitterConfig();
@@ -2096,3 +2132,5 @@ void MainWindow::onFocusChanged(QWidget *old, QWidget *now)
 }
 
 } // namespace
+
+#include "moc_mainwindow.cpp"
