@@ -179,7 +179,7 @@ Q_SIGNALS:
     void toggleFullScreenRequested();
 
 private:
-    QGraphicsWidget *mWidget;
+    QGraphicsWidget *mWidget = nullptr;
 };
 
 /**
@@ -196,7 +196,7 @@ public:
     }
     Document::Ptr document() const override
     {
-        return Document::Ptr();
+        return {};
     }
     void setDocument(const Document::Ptr &) override
     {
